import { captureException, getClient, getCurrentScope } from "@sentry/core";
import { H3Error } from "h3";
import { extractErrorContext, flushIfServerless } from "../utils.js";
export async function sentryCaptureErrorHook(error, errorContext) {
  const sentryClient = getClient();
  const sentryClientOptions = sentryClient?.getOptions();
  if (sentryClientOptions && "enableNitroErrorHandler" in sentryClientOptions && sentryClientOptions.enableNitroErrorHandler === false) {
    return;
  }
  if (error instanceof H3Error) {
    if (error.statusCode >= 300 && error.statusCode < 500) {
      return;
    }
  }
  const { method, path } = {
    method: errorContext.event?._method ? errorContext.event._method : "",
    path: errorContext.event?._path ? errorContext.event._path : null
  };
  if (path) {
    getCurrentScope().setTransactionName(`${method} ${path}`);
  }
  const structuredContext = extractErrorContext(errorContext);
  captureException(error, {
    captureContext: { contexts: { nuxt: structuredContext } },
    mechanism: { handled: false }
  });
  await flushIfServerless();
}
