import { getActiveSpan, getRootSpan, logger, SEMANTIC_ATTRIBUTE_SENTRY_SOURCE } from "@sentry/core";
export function updateRouteBeforeResponse(event) {
  if (!event.context.matchedRoute) {
    return;
  }
  const matchedRoutePath = event.context.matchedRoute.path;
  if (matchedRoutePath && matchedRoutePath !== event._path) {
    if (matchedRoutePath === "/**") {
      return;
    }
    const activeSpan = getActiveSpan();
    if (!activeSpan) {
      return;
    }
    const rootSpan = getRootSpan(activeSpan);
    if (!rootSpan) {
      return;
    }
    rootSpan.setAttributes({
      [SEMANTIC_ATTRIBUTE_SENTRY_SOURCE]: "route",
      "http.route": matchedRoutePath
    });
    const params = event.context?.params;
    if (params && typeof params === "object") {
      Object.entries(params).forEach(([key, value]) => {
        rootSpan.setAttributes({
          [`url.path.parameter.${key}`]: String(value),
          [`params.${key}`]: String(value)
        });
      });
    }
    logger.log(`Updated transaction name for parametrized route: ${matchedRoutePath}`);
  }
}
