import { getDefaultIsolationScope, getIsolationScope, logger, withIsolationScope } from "@sentry/core";
import { defineNitroPlugin } from "nitropack/runtime";
import { sentryCaptureErrorHook } from "../hooks/captureErrorHook.js";
import { updateRouteBeforeResponse } from "../hooks/updateRouteBeforeResponse.js";
import { addSentryTracingMetaTags, flushIfServerless } from "../utils.js";
export default defineNitroPlugin((nitroApp) => {
  nitroApp.h3App.handler = patchEventHandler(nitroApp.h3App.handler);
  nitroApp.hooks.hook("beforeResponse", updateRouteBeforeResponse);
  nitroApp.hooks.hook("error", sentryCaptureErrorHook);
  nitroApp.hooks.hook("render:html", (html) => {
    addSentryTracingMetaTags(html.head);
  });
});
function patchEventHandler(handler) {
  return new Proxy(handler, {
    async apply(handlerTarget, handlerThisArg, handlerArgs) {
      const isolationScope = getIsolationScope();
      const newIsolationScope = isolationScope === getDefaultIsolationScope() ? isolationScope.clone() : isolationScope;
      logger.log(
        `Patched h3 event handler. ${isolationScope === newIsolationScope ? "Using existing" : "Created new"} isolation scope.`
      );
      return withIsolationScope(newIsolationScope, async () => {
        try {
          return await handlerTarget.apply(handlerThisArg, handlerArgs);
        } finally {
          await flushIfServerless();
        }
      });
    }
  });
}
