import type { Nuxt } from '@nuxt/schema';
import { type SentryRollupPluginOptions } from '@sentry/rollup-plugin';
import { type SentryVitePluginOptions } from '@sentry/vite-plugin';
import type { NitroConfig } from 'nitropack';
import type { SentryNuxtModuleOptions } from '../common/types';
/**
 * Whether the user enabled (true, 'hidden', 'inline') or disabled (false) source maps
 */
export type UserSourceMapSetting = 'enabled' | 'disabled' | 'unset' | undefined;
/** A valid source map setting */
export type SourceMapSetting = boolean | 'hidden' | 'inline';
/**
 *  Setup source maps for Sentry inside the Nuxt module during build time (in Vite for Nuxt and Rollup for Nitro).
 */
export declare function setupSourceMaps(moduleOptions: SentryNuxtModuleOptions, nuxt: Nuxt): void;
/**
 *  Generates source maps upload options for the Sentry Vite and Rollup plugin.
 *
 *  Only exported for Testing purposes.
 */
export declare function getPluginOptions(moduleOptions: SentryNuxtModuleOptions, shouldDeleteFilesFallback?: {
    client: boolean;
    server: boolean;
}): SentryVitePluginOptions | SentryRollupPluginOptions;
/** only exported for tests */
export declare function extractNuxtSourceMapSetting(nuxt: {
    options: {
        sourcemap?: SourceMapSetting | {
            server?: SourceMapSetting;
            client?: SourceMapSetting;
        };
    };
}, runtime: 'client' | 'server' | undefined): SourceMapSetting | undefined;
/** only exported for testing  */
export declare function changeNuxtSourceMapSettings(nuxt: Nuxt, sentryModuleOptions: SentryNuxtModuleOptions): {
    client: UserSourceMapSetting;
    server: UserSourceMapSetting;
};
/** Logs warnings about potentially conflicting source map settings.
 *  Configures `sourcemapExcludeSources` in Nitro to make source maps usable in Sentry.
 *
 * only exported for testing
 */
export declare function validateNitroSourceMapSettings(nuxt: {
    options: {
        sourcemap?: SourceMapSetting | {
            server?: SourceMapSetting;
        };
    };
}, nitroConfig: NitroConfig, sentryModuleOptions: SentryNuxtModuleOptions): void;
//# sourceMappingURL=sourceMaps.d.ts.map